//+---------------------------------------------------------------------------+
//|                                                 Custom MACD-Histogram.mq4 |
//|                      Copyright  2010, FXBay - Vietnamese FX Trading Team |
//|                                                      http://www.fxbay.net |
//+---------------------------------------------------------------------------+
#property  copyright "Copyright  2010, FXBay - Vietnamese FX Trading Team"
#property  link      "http://www.fxbay.net/"

//---- indicator settings
#property  indicator_separate_window
#property  indicator_buffers 3
#property  indicator_color1  DarkTurquoise
#property  indicator_color2  Red
#property  indicator_color3  Gray
#property  indicator_width1  1

//---- indicator parameters
extern int FastEMA=12;
extern int SlowEMA=26;
extern int SignalEMA=9;


//---- indicator buffers
double     MACD_Buffer[];
double     MACD_Buffer5m[];
double     MACD_Buffer15m[];
double     MACD_Buffer30m[];
double     MACD_BufferH[];
double     MACD_Buffer4H[];
double     SIGNAL_Buffer[];
double     HISTOGRAM_Buffer[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init() {
//---- drawing settings
   SetIndexStyle(0,DRAW_LINE);
   SetIndexStyle(1,DRAW_LINE);
   SetIndexStyle(2,DRAW_HISTOGRAM);
   
   SetIndexDrawBegin(1,SignalEMA);
   IndicatorDigits(Digits+1);
   
//---- indicator buffers mapping
   SetIndexBuffer(0,MACD_Buffer);
   SetIndexBuffer(1,SIGNAL_Buffer);
   SetIndexBuffer(2,HISTOGRAM_Buffer);
   
//---- name for DataWindow and indicator subwindow label
   IndicatorShortName("FXBay - MACD ("+FastEMA+","+SlowEMA+","+SignalEMA+")");
   SetIndexLabel(0,"MACD");
   SetIndexLabel(1,"Signal");
   SetIndexLabel(2,"Histogram");
   
//---- initialization done
   return(0);
}

//+------------------------------------------------------------------+
//| Moving Averages Convergence/Divergence                           |
//+------------------------------------------------------------------+
int start() {

	int i;
	
	int limit;
	int counted_bars = IndicatorCounted();
	if(counted_bars < 0) return(-1);   //---- check for possible errors
	if(counted_bars > 0) counted_bars--;   //---- the last counted bar will be recounted
	limit = Bars - counted_bars;

//---- Draw MACD line
	for(i=0; i<limit; i++) 	//-- loop from the current bar to the first bar
		MACD_Buffer[i] = iMA(NULL,0,FastEMA,0,MODE_EMA,PRICE_CLOSE,i) - iMA(NULL,0,SlowEMA,0,MODE_EMA,PRICE_CLOSE,i);
	for(i=limit; i>=0; i--) {	//-- same loop above
		SIGNAL_Buffer[i] = iMAOnArray(MACD_Buffer,Bars,SignalEMA,0,MODE_SMA,i);
		HISTOGRAM_Buffer[i] = MACD_Buffer[i] - SIGNAL_Buffer[i];
	//	---------------------------------------------------------------------------
	double fst5m = iMA(NULL,5,FastEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double fst15m = iMA(NULL,15,FastEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double fst30m = iMA(NULL,30,FastEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double fstH = iMA(NULL,60,FastEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double fst4H = iMA(NULL,240,FastEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double slu5m = iMA(NULL,5,SlowEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double slu15m = iMA(NULL,15,SlowEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double slu30m = iMA(NULL,30,SlowEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double sluH = iMA(NULL,60,SlowEMA,0,MODE_EMA,PRICE_CLOSE,i);
	double slu4H = iMA(NULL,240,SlowEMA,0,MODE_EMA,PRICE_CLOSE,i);
	//	---------------------------------------------------------------------------
	MACD_Buffer5m[i] = (fst5m - slu5m);
	MACD_Buffer15m[i]= (fst15m - slu15m);
	MACD_Buffer30m[i]= (fst30m - slu30m);
	MACD_BufferH[i]  = (fstH - sluH);
	MACD_Buffer4H[i] = (fst4H - slu4H);
	//	---------------------------------5m----------------------------------------
	
	double price5m = 0;
	if (MACD_Buffer5m[i]> 0 && MACD_Buffer5m[i+1]<0) price5m = fst5m;
	if (MACD_Buffer5m[i]< 0 && MACD_Buffer5m[i+1]>0) price5m = slu5m;
	
	if (price5m!=0)
	{
	   ObjectCreate("crssup5m",OBJ_HLINE,0,0,price5m);
	      ObjectSet("crssup5m",OBJPROP_COLOR,Red);
	      ObjectSet("crssup5m",OBJPROP_PRICE1,price5m);
	} 
	//---------------------------------15m------------------------------------
	double price15m = 0;
	if (MACD_Buffer15m[i]> 0 && MACD_Buffer15m[i+1]<0) price15m = fst15m;
	if (MACD_Buffer15m[i]< 0 && MACD_Buffer15m[i+1]>0) price15m = slu15m;
	
	if (price15m!=0)
	{
	   ObjectCreate("crssup15m",OBJ_HLINE,0,0,price15m);
	      ObjectSet("crssup15m",OBJPROP_COLOR,Red);
	      ObjectSet("crssup15m",OBJPROP_PRICE1,price15m);
	}      
	//-----------------------------30m---------------------------------------
	double price30 = 0;
	if (MACD_Buffer30m[i]> 0 && MACD_Buffer30m[i+1]<0) price30 = fst30m;
	if (MACD_Buffer30m[i]< 0 && MACD_Buffer30m[i+1]>0) price30 = slu30m;
	
	if (price30!=0)
	{
	   ObjectCreate("crssup30m",OBJ_HLINE,0,0,price30);
	      ObjectSet("crssup30m",OBJPROP_COLOR,Red);
	      ObjectSet("crssup30m",OBJPROP_PRICE1,price30);
	}      
	//-----------------------------H----------------------------------------
	double priceH = 0;
	if (MACD_BufferH[i]> 0 && MACD_BufferH[i+1]<0) priceH = fstH;
	if (MACD_BufferH[i]< 0 && MACD_BufferH[i+1]>0) priceH = sluH;
	
	if (priceH!=0)
	{
	   ObjectCreate("crssupH",OBJ_HLINE,0,0,priceH);
	      ObjectSet("crssupH",OBJPROP_COLOR,Red);
	      ObjectSet("crssupH",OBJPROP_PRICE1,priceH);
	}      
	//---------------------------4H-----------------------------------------
	double price4H = 0;
	if (MACD_Buffer4H[i]> 0 && MACD_Buffer4H[i+1]<0) price4H = fst4H;
	if (MACD_Buffer4H[i]< 0 && MACD_Buffer4H[i+1]>0) price4H = slu4H;
	
	if (price4H !=0)
	{
	   ObjectCreate("crssup4H",OBJ_HLINE,0,0,price4H);
	      ObjectSet("crssup4H",OBJPROP_COLOR,Red);
	      ObjectSet("crssup4H",OBJPROP_PRICE1,price4H);
	}      
	
	
	
	
	     
   }

//---- Draw Signal line and Histogram
//---- Done
   return(0);
}

//+-----------------------------------------------------------------+